# Generated by Django 2.2.2 on 2019-06-15 08:37


from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='History',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                ('method', isc_common.fields.code_field.CodeField()),
                ('path', isc_common.fields.code_field.CodeField()),
                ('data', django.db.models.JSONField(default=dict)),
            ],
            options={
                'verbose_name': 'History',
            },
        ),
    ]
