from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('tracker', '0022_auto_20190517_1802'),
    ]
    atomic = True

    operations = [
        # migrations.RunPython(fill),
    ]
