# Generated by Django 3.0.3 on 2020-02-09 16:48

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0041_progresses_showcancel'),
    ]

    operations = [
        migrations.AddField(
            model_name='progresses',
            name='type',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
