# Generated by Django 2.2.7 on 2019-11-16 10:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0006_untrackeduseragent'),
    ]

    operations = [
        migrations.CreateModel(
            name='BannedIP',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip_address', models.GenericIPAddressField(help_text='The IP address that should be banned', verbose_name='IP Address')),
            ],
            options={
                'verbose_name': 'Banned IP',
                'verbose_name_plural': 'Banned IPs',
                'ordering': ('ip_address',),
            },
        ),
    ]
