# Generated by Django 2.1.7 on 2019-02-16 20:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0002_rec_admin_group'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='permissions',
        ),
        migrations.RemoveField(
            model_name='usergroup',
            name='permissions',
        ),
    ]
