# Generated by Django 3.0.8 on 2020-08-03 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0080_auto_20200208_1350'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='messages',
            name='Messages_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='messages',
            name='Messages_unique_constraint_1',
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(('guid', None), ('importance', None), ('message', None)), fields=('checksum', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(('importance', None), ('message', None)), fields=('checksum', 'guid', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(('guid', None), ('message', None)), fields=('checksum', 'importance', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(message=None), fields=('checksum', 'guid', 'importance', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(('guid', None), ('importance', None)), fields=('checksum', 'message', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(importance=None), fields=('checksum', 'guid', 'message', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(condition=models.Q(guid=None), fields=('checksum', 'importance', 'message', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='messages',
            constraint=models.UniqueConstraint(fields=('checksum', 'guid', 'importance', 'message', 'state', 'theme', 'to_whom', 'user'), name='Messages_unique_constraint_7'),
        ),
    ]
