# Generated by Django 2.2.5 on 2019-09-05 05:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0057_auto_20190904_1843'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='messages',
            options={'ordering': ('lastmodified',), 'verbose_name': 'Сообщения'},
        ),
    ]
