# Generated by Django 2.2.7 on 2019-11-16 18:27

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0011_auto_20191116_1318'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='visitor',
            unique_together={('username', 'ip_address')},
        ),
    ]
