# Generated by Django 2.1.7 on 2019-03-20 10:15

import django.utils.timezone
from django.conf import settings
from django.db import migrations, models

import isc_common.fields.code_field
import isc_common.fields.related


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0012_auto_20190307_0100'),
    ]

    operations = [
        migrations.CreateModel(
            name='History',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('modified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('model', isc_common.fields.code_field.CodeField(verbose_name='Наименование таблицы')),
                ('data', django.db.models.JSONField(verbose_name='Данные учавствующие в транзакции')),
                ('old_data', django.db.models.JSONField(verbose_name='Данные учавствующие в транзакции (старые)')),
                ('description', models.TextField(verbose_name='Описание транзакции')),
                ('user', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL, verbose_name='Пользователь сделавший изменение')),
            ],
            options={
                'verbose_name': 'History',
            },
        ),
    ]
