# Generated by Django 2.2.2 on 2019-06-10 14:36

import django.utils.timezone
from django.conf import settings
from django.db import migrations, models
from django.db.models import JSONField

import isc_common.fields.code_field
import isc_common.fields.related


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0025_widgets_trees_parent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='history',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='history',
            name='deliting',
        ),
        migrations.RemoveField(
            model_name='history',
            name='description',
        ),
        migrations.RemoveField(
            model_name='history',
            name='editing',
        ),
        migrations.RemoveField(
            model_name='history',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='history',
            name='lastmodified',
        ),
        migrations.RemoveField(
            model_name='history',
            name='model',
        ),
        migrations.RemoveField(
            model_name='history',
            name='modified',
        ),
        migrations.RemoveField(
            model_name='history',
            name='old_data',
        ),
        migrations.AddField(
            model_name='history',
            name='date',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='history',
            name='method',
            field=isc_common.fields.code_field.CodeField(),
        ),
        migrations.AddField(
            model_name='history',
            name='path',
            field=isc_common.fields.code_field.CodeField(),
        ),
        migrations.AlterField(
            model_name='history',
            name='data',
            field=django.db.models.JSONField(default=dict),
        ),
        migrations.AlterField(
            model_name='history',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='history',
            name='user',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
    ]
