# Generated by Django 2.2.4 on 2019-08-21 12:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0012_holidays_props'),
    ]

    operations = [
        migrations.AlterField(
            model_name='calendars',
            name='begindate',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Начало'),
        ),
        migrations.AlterField(
            model_name='calendars',
            name='enddate',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Конец'),
        ),
    ]
