# Generated by Django 2.2.7 on 2019-11-16 10:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0005_visitor'),
    ]

    operations = [
        migrations.CreateModel(
            name='UntrackedUserAgent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('keyword', models.CharField(help_text='Part or all of a user-agent string.  For example, "Googlebot" here will be found in "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)" and that visitor will not be tracked.', max_length=255, verbose_name='keyword')),
            ],
            options={
                'verbose_name': 'Untracked User-Agent',
                'verbose_name_plural': 'Untracked User-Agents',
                'ordering': ('keyword',),
            },
        ),
    ]
