# Generated by Django 2.2.5 on 2019-09-05 17:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0004_auto_20190830_2250'),
    ]

    operations = [
        migrations.AddField(
            model_name='chat_user_user',
            name='common_id',
            field=models.PositiveIntegerField(default=None),
        ),
    ]
