# Generated by Django 2.2.4 on 2019-08-19 12:05

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('twits', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='chat_users',
            unique_together={('user', 'chat')},
        ),
    ]
