# Generated by Django 2.2.4 on 2019-08-06 06:44

from django.db import migrations
import isc_common.fields.description_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0034_messages_theme_access'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='messages_state',
            options={'verbose_name': 'Состояние задачи'},
        ),
        migrations.AlterModelOptions(
            name='messages_theme',
            options={'verbose_name': 'Темы задач'},
        ),
        migrations.AlterModelOptions(
            name='messages_theme_access',
            options={'verbose_name': 'Доступы к темам задач'},
        ),
        migrations.AlterModelOptions(
            name='messages_whom',
            options={'verbose_name': 'Получатель задач'},
        ),
        migrations.AlterField(
            model_name='messages',
            name='message',
            field=isc_common.fields.description_field.DescriptionField(verbose_name='Тело задачи'),
        ),
    ]
