# Generated by Django 2.2.5 on 2019-09-05 17:01

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('twits', '0005_chat_user_user_common_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chat_user_user',
            name='common_id',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterUniqueTogether(
            name='chat_user_user',
            unique_together={('user_sender', 'user_reciver', 'common_id')},
        ),
    ]
